fnss.adapters.autonetkit.to_autonetkit — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »

# fnss.adapters.autonetkit.to_autonetkit

`to_autonetkit`(topology)

  Convert an FNSS topology into a NetworkX graph object compatible for AutoNetKit.

  The returned graph can be saved into a GraphML file using NetworkX write_graphml function and then passed to AutoNetKit as command line parameter.

  The current implementation of this function only renames the weight attribute from weight to ospf_cost

  Parameters : | topology : FNSS Topology Autonetkit topology object
  Returns : | ank_graph : FNSS topology an FNSS topology compatible for import to AutoNetKit

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »